;;; ~/.doom.d/+ui.el -*- lexical-binding: t; -*-
;; Appearance settings
;; Set Font and theme
(setq doom-font (font-spec :family "Iosevka Medium" :size 26)
      doom-theme 'doom-one)
;; Display Magit status in fullscreen
(after! magit
  (setq magit-display-buffer-function #'magit-display-buffer-fullframe-status-v1))
;; Match pdf-tools colors to the theme and fit to page by default
(after! pdf-tools
  (setq pdf-view-midnight-colors '("#BBC2CF" . "#282C34"))
  (add-hook 'pdf-tools-enabled-hook 'pdf-view-midnight-minor-mode))
;; Customize modeline
(setq doom-modeline-major-mode-icon t
      doom-modeline-persp-name t
      doom-modeline-buffer-encoding nil)
;; Hide direnv environment variables popup
(setq direnv-always-show-summary nil)
;; Change splash-screen banner
(setq fancy-splash-image "~/.doom.d/assets/emacs.svg")
;; Remove distracting LSP UI elements
(after! eglot
  (setq eldoc-echo-area-use-multiline-p nil)
  (set-popup-rule! "^\\*eglot-help" :size 0.2 :quit t :select t))
;; Shrink minibuffer
(after! vertico
  (setq vertico-count 8))
;; Eliminate gaps between windows
(after! frame
  (remove-hook 'doom-init-ui-hook #'window-divider-mode))
;; Shrink terminal buffer
(set-popup-rule! "*doom:vterm-popup:*" :size 0.25 :vslot -4 :select t :quit nil :ttl 0)
;; Show matching parenthesis on the minibuffer
(after! smartparens (show-smartparens-global-mode t))
;; Modify the splash screen actions
(assoc-delete-all "Jump to bookmark" +doom-dashboard-menu-sections)
(assoc-delete-all "Open private configuration" +doom-dashboard-menu-sections)
(assoc-delete-all "Open documentation" +doom-dashboard-menu-sections)
(add-to-list '+doom-dashboard-menu-sections
             '("Open email client"
               :icon (all-the-icons-octicon "mail" :face 'doom-dashboard-menu-title)
               :when (featurep! :email mu4e)
               :face (:inherit (doom-dashboard-menu-title bold))
               :action =mu4e) t)
(add-to-list '+doom-dashboard-menu-sections
             '("RSS reader"
               :icon (all-the-icons-octicon "rss" :face 'doom-dashboard-menu-title)
               :when (featurep! :app rss)
               :face (:inherit (doom-dashboard-menu-title bold))
               :action =rss) t)
(add-to-list '+doom-dashboard-menu-sections
             '("Read saved articles"
               :icon (all-the-icons-octicon "book" :face 'doom-dashboard-menu-title)
               :face (:inherit (doom-dashboard-menu-title bold))
               :action =wallabag) t)
